==> strace_5.5.orig.tar.xz: strace-5.5/mpers_xlat.h <==
extern const struct xlat block_ioctl_cmds[];
extern const struct xlat blkpg_ops[];
extern const struct xlat btrfs_balance_args[];
extern const struct xlat btrfs_balance_ctl_cmds[];
extern const struct xlat btrfs_balance_flags[];
extern const struct xlat btrfs_balance_state[];
extern const struct xlat btrfs_compress_types[];
extern const struct xlat btrfs_cont_reading_from_srcdev_mode[];
extern const struct xlat btrfs_defrag_flags[];
extern const struct xlat btrfs_dev_replace_cmds[];
extern const struct xlat btrfs_dev_replace_results[];
extern const struct xlat btrfs_dev_replace_state[];
extern const struct xlat btrfs_dev_stats_flags[];
extern const struct xlat btrfs_dev_stats_values[];
extern const struct xlat btrfs_features_compat[];
extern const struct xlat btrfs_features_compat_ro[];
extern const struct xlat btrfs_features_incompat[];
extern const struct xlat btrfs_key_types[];
extern const struct xlat btrfs_logical_ino_args_flags[];
extern const struct xlat btrfs_qgroup_ctl_cmds[];
extern const struct xlat btrfs_qgroup_inherit_flags[];
extern const struct xlat btrfs_qgroup_limit_flags[];
extern const struct xlat btrfs_qgroup_status_flags[];
extern const struct xlat btrfs_scrub_flags[];
extern const struct xlat btrfs_send_flags[];
extern const struct xlat btrfs_snap_flags_v2[];
extern const struct xlat btrfs_space_info_flags[];
extern const struct xlat btrfs_tree_objectids[];
extern const struct xlat msgctl_flags[];
extern const struct xlat shmctl_flags[];
extern const struct xlat loop_cmds[];
extern const struct xlat loop_flags_options[];
extern const struct xlat loop_crypt_type_options[];
extern const struct xlat mtd_mode_options[];
extern const struct xlat mtd_file_mode_options[];
extern const struct xlat mtd_type_options[];
extern const struct xlat mtd_flags_options[];
extern const struct xlat mtd_otp_options[];
extern const struct xlat mtd_nandecc_options[];
extern const struct xlat perf_ioctl_cmds[];
extern const struct xlat perf_ioctl_flags[];
extern const struct xlat mq_attr_flags[];
extern const struct xlat sigev_value[];
extern const struct xlat elf_em[];
extern const struct xlat audit_arch[];
extern const struct xlat sigbus_codes[];
extern const struct xlat sigchld_codes[];
extern const struct xlat sigfpe_codes[];
extern const struct xlat sigill_codes[];
extern const struct xlat siginfo_codes[];
extern const struct xlat sigpoll_codes[];
extern const struct xlat sigprof_codes[];
extern const struct xlat sigsegv_codes[];
extern const struct xlat sigsys_codes[];
extern const struct xlat sigtrap_codes[];
extern const struct xlat sigemt_codes[];
extern const struct xlat sg_io_info[];
extern const struct xlat sg_io_dxfer_direction[];
extern const struct xlat sg_io_flags[];
extern const struct xlat sigaltstack_flags[];
extern const struct xlat iffflags[];
extern const struct xlat arp_hardware_types[];
extern const struct xlat v4l2_pix_fmts[];
extern const struct xlat v4l2_sdr_fmts[];
extern const struct xlat v4l2_device_capabilities_flags[];
extern const struct xlat v4l2_buf_types[];
extern const struct xlat v4l2_format_description_flags[];
extern const struct xlat v4l2_fields[];
extern const struct xlat v4l2_colorspaces[];
extern const struct xlat v4l2_vbi_flags[];
extern const struct xlat v4l2_sliced_flags[];
extern const struct xlat v4l2_memories[];
extern const struct xlat v4l2_buf_flags[];
extern const struct xlat v4l2_streaming_capabilities[];
extern const struct xlat v4l2_capture_modes[];
extern const struct xlat v4l2_input_types[];
extern const struct xlat v4l2_control_classes[];
extern const struct xlat v4l2_control_id_bases[];
extern const struct xlat v4l2_control_ids[];
extern const struct xlat v4l2_tuner_types[];
extern const struct xlat v4l2_tuner_capabilities[];
extern const struct xlat v4l2_tuner_rxsubchanses[];
extern const struct xlat v4l2_tuner_audmodes[];
extern const struct xlat v4l2_control_types[];
extern const struct xlat v4l2_control_flags[];
extern const struct xlat v4l2_framesize_types[];
extern const struct xlat v4l2_frameinterval_types[];

==> strace-5.10.tar.xz: strace-5.10/mpers_xlat.h <==
extern const struct xlat block_ioctl_cmds[];
extern const struct xlat blkpg_ops[];
extern const struct xlat btrfs_balance_args[];
extern const struct xlat btrfs_balance_ctl_cmds[];
extern const struct xlat btrfs_balance_flags[];
extern const struct xlat btrfs_balance_state[];
extern const struct xlat btrfs_compress_types[];
extern const struct xlat btrfs_cont_reading_from_srcdev_mode[];
extern const struct xlat btrfs_defrag_flags[];
extern const struct xlat btrfs_dev_replace_cmds[];
extern const struct xlat btrfs_dev_replace_results[];
extern const struct xlat btrfs_dev_replace_state[];
extern const struct xlat btrfs_dev_stats_flags[];
extern const struct xlat btrfs_dev_stats_values[];
extern const struct xlat btrfs_features_compat[];
extern const struct xlat btrfs_features_compat_ro[];
extern const struct xlat btrfs_features_incompat[];
extern const struct xlat btrfs_key_types[];
extern const struct xlat btrfs_logical_ino_args_flags[];
extern const struct xlat btrfs_qgroup_ctl_cmds[];
extern const struct xlat btrfs_qgroup_inherit_flags[];
extern const struct xlat btrfs_qgroup_limit_flags[];
extern const struct xlat btrfs_qgroup_status_flags[];
extern const struct xlat btrfs_scrub_flags[];
extern const struct xlat btrfs_send_flags[];
extern const struct xlat btrfs_snap_flags_v2[];
extern const struct xlat btrfs_space_info_flags[];
extern const struct xlat btrfs_tree_objectids[];
extern const struct xlat hdio_drive_cmds[];
extern const struct xlat msgctl_flags[];
extern const struct xlat semctl_flags[];
extern const struct xlat shmctl_flags[];
extern const struct xlat loop_cmds[];
extern const struct xlat loop_flags_options[];
extern const struct xlat loop_crypt_type_options[];
extern const struct xlat mtd_mode_options[];
extern const struct xlat mtd_file_mode_options[];
extern const struct xlat mtd_type_options[];
extern const struct xlat mtd_flags_options[];
extern const struct xlat mtd_otp_options[];
extern const struct xlat mtd_nandecc_options[];
extern const struct xlat perf_ioctl_cmds[];
extern const struct xlat perf_ioctl_flags[];
extern const struct xlat mq_attr_flags[];
extern const struct xlat sigev_value[];
extern const struct xlat elf_em[];
extern const struct xlat audit_arch[];
extern const struct xlat sigbus_codes[];
extern const struct xlat sigchld_codes[];
extern const struct xlat sigfpe_codes[];
extern const struct xlat sigill_codes[];
extern const struct xlat siginfo_codes[];
extern const struct xlat sigpoll_codes[];
extern const struct xlat sigprof_codes[];
extern const struct xlat sigsegv_codes[];
extern const struct xlat sigsys_codes[];
extern const struct xlat sigtrap_codes[];
extern const struct xlat sigemt_codes[];
extern const struct xlat rtc_vl_flags[];
extern const struct xlat rtc_ioctl_cmds[];
extern const struct xlat sg_io_info[];
extern const struct xlat sg_io_dxfer_direction[];
extern const struct xlat sg_io_flags[];
extern const struct xlat sigaltstack_flags[];
extern const struct xlat iffflags[];
extern const struct xlat arp_hardware_types[];
extern const struct xlat v4l2_pix_fmts[];
extern const struct xlat v4l2_sdr_fmts[];
extern const struct xlat v4l2_ioctl_cmds[];
extern const struct xlat v4l2_device_capabilities_flags[];
extern const struct xlat v4l2_buf_types[];
extern const struct xlat v4l2_format_description_flags[];
extern const struct xlat v4l2_fields[];
extern const struct xlat v4l2_colorspaces[];
extern const struct xlat v4l2_vbi_flags[];
extern const struct xlat v4l2_sliced_flags[];
extern const struct xlat v4l2_memories[];
extern const struct xlat v4l2_buf_flags[];
extern const struct xlat v4l2_buf_flags_ts_type[];
extern const struct xlat v4l2_buf_flags_ts_src[];
extern const struct xlat v4l2_buf_flags_masks[];
extern const struct xlat v4l2_streaming_capabilities[];
extern const struct xlat v4l2_capture_modes[];
extern const struct xlat v4l2_input_types[];
extern const struct xlat v4l2_control_classes[];
extern const struct xlat v4l2_control_id_bases[];
extern const struct xlat v4l2_control_ids[];
extern const struct xlat v4l2_control_query_flags[];
extern const struct xlat v4l2_tuner_types[];
extern const struct xlat v4l2_tuner_capabilities[];
extern const struct xlat v4l2_tuner_rxsubchanses[];
extern const struct xlat v4l2_tuner_audmodes[];
extern const struct xlat v4l2_control_types[];
extern const struct xlat v4l2_control_flags[];
extern const struct xlat v4l2_framesize_types[];
extern const struct xlat v4l2_frameinterval_types[];
